/* Copyright (c) 2002-2012 Croteam Ltd. 
This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation


This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */

// Animation names
#define WOMAN_ANIM_AIRATTACK01 0
#define WOMAN_ANIM_AIRATTACK02 1
#define WOMAN_ANIM_AIRDEATH 2
#define WOMAN_ANIM_AIRFLY 3
#define WOMAN_ANIM_AIRSTAND 4
#define WOMAN_ANIM_AIRWOUND02 5
#define WOMAN_ANIM_GROUNDDEATH01 6
#define WOMAN_ANIM_GROUNDDEATH02 7
#define WOMAN_ANIM_GROUNDTOAIR 8
#define WOMAN_ANIM_AIRTOGROUND 9
#define WOMAN_ANIM_GROUNDWALK 10
#define WOMAN_ANIM_GROUNDRUN 11
#define WOMAN_ANIM_GROUNDATTACK01 12
#define WOMAN_ANIM_GROUNDATTACK02 13
#define WOMAN_ANIM_GROUNDWOUND04 14
#define WOMAN_ANIM_GROUNDSTAND 15

// Color names

// Patch names

// Names of collision boxes
#define WOMAN_COLLISION_BOX_GROUND 0
#define WOMAN_COLLISION_BOX_AIR 1
#define WOMAN_COLLISION_BOX_DEATH 2

// Attaching position names

// Sound names
